@@ -41,7 +41,7 @@ from tests.util import delete_squeak
 from tests.util import download_offers
 from tests.util import download_squeak
 from tests.util import download_squeaks
-from tests.util import download_squeaks_for_address
+from tests.util import download_squeaks_for_pubkey
 from tests.util import free_price
 from tests.util import get_connected_peer
 from tests.util import get_connected_peers
@@ -50,6 +50,8 @@ from tests.util import get_external_address
 from tests.util import get_hash
 from tests.util import get_network
 from tests.util import get_peer_by_address
+from tests.util import get_profile_by_pubkey
+from tests.util import get_pubkey_squeak_displays
 from tests.util import get_search_squeaks
 from tests.util import get_sell_price
 from tests.util import get_squeak_display
@@ -59,6 +61,7 @@ from tests.util import import_signing_profile
 from tests.util import make_squeak
 from tests.util import open_peer_connection
 from tests.util import peer_connection
+from tests.util import public_key_from_hex
 from tests.util import send_coins
 from tests.util import set_sell_price
 from tests.util import set_twitter_bearer_token
@@ -139,17 +142,20 @@ def test_reprocess_received_payments(admin_stub):
 def test_get_profile(admin_stub, signing_profile_id):
     # Get the squeak profile
     squeak_profile = get_squeak_profile(admin_stub, signing_profile_id)
-    address = squeak_profile.address
+    # address = squeak_profile.address
+    pubkey = squeak_profile.pubkey
     name = squeak_profile.profile_name
 
     # Get the same squeak profile by address
-    get_squeak_profile_by_address_response = admin_stub.GetSqueakProfileByAddress(
-        squeak_admin_pb2.GetSqueakProfileByAddressRequest(
-            address=address,
-        )
-    )
-    assert address == get_squeak_profile_by_address_response.squeak_profile.address
-    assert name == get_squeak_profile_by_address_response.squeak_profile.profile_name
+    # get_squeak_profile_by_pubkey_response = admin_stub.GetSqueakProfileByAddress(
+    #     squeak_admin_pb2.GetSqueakProfileByAddressRequest(
+    #         pubkey=pubkey,
+    #     )
+    # )
+    profile = get_profile_by_pubkey(admin_stub, pubkey)
+    # assert address == get_squeak_profile_by_address_response.squeak_profile.address
+    assert pubkey == profile.pubkey
+    assert name == profile.profile_name
 
     # Get the same squeak profile by name
     get_squeak_profile_by_name_response = admin_stub.GetSqueakProfileByName(
@@ -157,7 +163,7 @@ def test_get_profile(admin_stub, signing_profile_id):
             name=name,
         )
     )
-    assert address == get_squeak_profile_by_name_response.squeak_profile.address
+    assert pubkey == get_squeak_profile_by_name_response.squeak_profile.pubkey
     assert name == get_squeak_profile_by_name_response.squeak_profile.profile_name
 
 
@@ -194,22 +200,25 @@ def test_make_squeak(admin_stub, signing_profile_id):
 
     # Get the squeak profile
     squeak_profile = get_squeak_profile(admin_stub, signing_profile_id)
-    squeak_profile_address = squeak_profile.address
+    squeak_profile_pubkey = squeak_profile.pubkey
     squeak_profile_name = squeak_profile.profile_name
 
     # Get all squeak displays for the known address
-    get_address_squeak_display_response = admin_stub.GetAddressSqueakDisplays(
-        squeak_admin_pb2.GetAddressSqueakDisplaysRequest(
-            address=squeak_profile_address,
-            limit=100,
-        ),
-    )
-    assert len(get_address_squeak_display_response.squeak_display_entries) == 1
+    # get_address_squeak_display_response = admin_stub.GetAddressSqueakDisplays(
+    #     squeak_admin_pb2.GetAddressSqueakDisplaysRequest(
+    #         pubkey=squeak_profile_pubkey,
+    #         limit=100,
+    #     ),
+    # )
+    address_squeak_displays = get_pubkey_squeak_displays(
+        admin_stub, squeak_profile_pubkey, 100)
+
+    assert len(address_squeak_displays) == 1
     for (
         squeak_display_entry
-    ) in get_address_squeak_display_response.squeak_display_entries:
+    ) in address_squeak_displays:
         assert squeak_display_entry.author.profile_name == squeak_profile_name
-        assert squeak_display_entry.author.address == squeak_profile_address
+        assert squeak_display_entry.author.pubkey == squeak_profile_pubkey
 
     # check serialized squeak hex string
     serialized_squeak_hex = get_squeak_display_entry.serialized_squeak_hex
@@ -280,7 +289,7 @@ def test_make_signing_profile(admin_stub):
     # Get the new squeak profile
     squeak_profile = get_squeak_profile(admin_stub, profile_id)
     assert squeak_profile.profile_name == profile_name
-    squeak_profile_address = squeak_profile.address
+    squeak_profile_pubkey = squeak_profile.pubkey
 
     # Get all signing profiles
     get_signing_profiles_response = admin_stub.GetSigningProfiles(
@@ -293,12 +302,13 @@ def test_make_signing_profile(admin_stub):
     assert profile_name in signing_profile_names
 
     # Get squeak profile by address
-    get_profile_by_address_response = admin_stub.GetSqueakProfileByAddress(
-        squeak_admin_pb2.GetSqueakProfileByAddressRequest(
-            address=squeak_profile_address
-        )
-    )
-    assert get_profile_by_address_response.squeak_profile.profile_name == profile_name
+    # get_profile_by_address_response = admin_stub.GetSqueakProfileByAddress(
+    #     squeak_admin_pb2.GetSqueakProfileByAddressRequest(
+    #         pubkey=squeak_profile_pubkey
+    #     )
+    # )
+    profile = get_profile_by_pubkey(admin_stub, squeak_profile_pubkey)
+    assert profile.profile_name == profile_name
 
     # Export the private key, delete the profile, and re-import it.
     get_private_key_response = admin_stub.GetSqueakProfilePrivateKey(
@@ -318,14 +328,14 @@ def test_make_signing_profile(admin_stub):
     # Get the new imported profile
     squeak_profile = get_squeak_profile(admin_stub, new_profile_id)
     assert squeak_profile.profile_name == "imported_profile_name"
-    assert squeak_profile.address == squeak_profile_address
+    assert squeak_profile.pubkey == squeak_profile_pubkey
 
 
-def test_make_contact_profile(admin_stub, squeak_address):
+def test_make_contact_profile(admin_stub, public_key):
     # Create a new contact profile
     contact_name = "test_contact_profile_name"
     contact_profile_id = create_contact_profile(
-        admin_stub, contact_name, squeak_address)
+        admin_stub, contact_name, public_key)
 
     # Get all contact profiles
     get_contact_profiles_response = admin_stub.GetContactProfiles(
@@ -350,10 +360,10 @@ def test_make_signing_profile_empty_name(admin_stub):
     assert "Profile name cannot be empty." in str(excinfo.value)
 
 
-def test_make_contact_profile_empty_name(admin_stub, squeak_address):
+def test_make_contact_profile_empty_name(admin_stub, public_key):
     # Try to create a new contact profile with an empty name
     with pytest.raises(Exception) as excinfo:
-        create_contact_profile(admin_stub, "", squeak_address)
+        create_contact_profile(admin_stub, "", public_key)
     assert "Profile name cannot be empty." in str(excinfo.value)
 
 
@@ -426,7 +436,7 @@ def test_set_profile_image(admin_stub, contact_profile_id, random_image, random_
     assert not squeak_profile.has_custom_profile_image
 
 
-def test_delete_profile(admin_stub, random_name, squeak_address, contact_profile_id):
+def test_delete_profile(admin_stub, random_name, public_key, contact_profile_id):
     # Delete the profile
     delete_profile(admin_stub, contact_profile_id)
 
@@ -441,13 +451,15 @@ def test_delete_profile(admin_stub, random_name, squeak_address, contact_profile
     )
     assert not get_squeak_profile_by_name_response.HasField("squeak_profile")
 
-    get_squeak_profile_by_address_response = admin_stub.GetSqueakProfileByAddress(
-        squeak_admin_pb2.GetSqueakProfileByAddressRequest(
-            address=squeak_address,
-        )
-    )
-    assert not get_squeak_profile_by_address_response.HasField(
-        "squeak_profile")
+    # get_squeak_profile_by_pubkey_response = admin_stub.GetSqueakProfileByAddress(
+    #     squeak_admin_pb2.GetSqueakProfileByAddressRequest(
+    #         pubkey=public_key.to_bytes().hex(),
+    #     )
+    # )
+    profile = get_profile_by_pubkey(admin_stub, public_key.to_bytes().hex())
+    # assert not get_squeak_profile_by_pubkey_response.HasField(
+    #     "squeak_profile")
+    assert profile is None
 
 
 def test_get_profile_private_key(admin_stub, signing_profile_id):
@@ -863,7 +875,7 @@ def test_download_single_squeak(
         assert item[0].squeak_hash == saved_squeak_hash
 
 
-def test_download_squeaks_for_address(
+def test_download_squeaks_for_pubkey(
     admin_stub,
     other_admin_stub,
     connected_tcp_peer_id,
@@ -871,9 +883,9 @@ def test_download_squeaks_for_address(
     saved_squeak_hash,
 ):
     squeak_profile = get_squeak_profile(admin_stub, signing_profile_id)
-    squeak_profile_address = squeak_profile.address
+    squeak_profile_pubkey = squeak_profile.pubkey
 
-    with subscribe_squeaks_for_address(other_admin_stub, squeak_profile_address) as subscription_queue:
+    with subscribe_squeaks_for_address(other_admin_stub, squeak_profile_pubkey) as subscription_queue:
 
         # Get the squeak display item (should be empty)
         squeak_display_entry = get_squeak_display(
@@ -890,8 +902,8 @@ def test_download_squeaks_for_address(
         assert len(get_buy_offers_response.offers) == 0
 
         # Download squeaks for address
-        download_result = download_squeaks_for_address(
-            other_admin_stub, squeak_profile_address)
+        download_result = download_squeaks_for_pubkey(
+            other_admin_stub, squeak_profile_pubkey)
         assert download_result.number_downloaded == 1
         assert download_result.number_requested == 10
 
@@ -1008,7 +1020,7 @@ def test_get_squeak_by_lookup(
 ):
     # Get the squeak profile
     squeak_profile = get_squeak_profile(admin_stub, signing_profile_id)
-    squeak_profile_address = squeak_profile.address
+    squeak_profile_pubkey = squeak_profile.pubkey
     squeak_profile.profile_name
 
     # Get the squeak display item
@@ -1019,7 +1031,7 @@ def test_get_squeak_by_lookup(
     # Sync squeaks
     download_result = download_squeaks(
         other_admin_stub,
-        [squeak_profile_address],
+        [squeak_profile_pubkey],
         -1,
         -1,
         None,
@@ -1043,12 +1055,13 @@ def test_subscribe_squeaks(
     # Get the squeak profile
     squeak_profile = get_squeak_profile(
         admin_stub, signing_profile_id)
-    squeak_profile_address = squeak_profile.address
+    squeak_profile_pubkey = squeak_profile.pubkey
     squeak_profile_name = squeak_profile.profile_name
 
     # Add the contact profile to the other server and set the profile to be following
+    public_key = public_key_from_hex(squeak_profile_pubkey)
     contact_profile_id = create_contact_profile(
-        other_admin_stub, squeak_profile_name, squeak_profile_address)
+        other_admin_stub, squeak_profile_name, public_key)
     other_admin_stub.SetSqueakProfileFollowing(
         squeak_admin_pb2.SetSqueakProfileFollowingRequest(
             profile_id=contact_profile_id,
